@@ -6,14 +6,11 @@ if TYPE_CHECKING:
     from openride.core.transform import Transform
 
 
-
 class Geometry(ABC):
-
     @abstractclassmethod
     def to_shapely(self) -> BaseGeometry:
         """Converts in a shapely.BaseGeometry object"""
 
     @abstractclassmethod
-    def transform(self, transform:'Transform') -> 'Geometry':
+    def transform(self, transform: "Transform") -> "Geometry":
         """Returns a transformed version of this object"""
-        
\ No newline at end of file
