@@ -1,5 +1,5 @@
 from openride import Polyline, Point, Transform
-from openride.core.numba.coordinate_systems import spherical_to_cartesian
+from openride.core.numba import spherical_to_cartesian
 from openride.test import get_pytest_benchmark
 from openride.test.random_core_generator import get_random
 
@@ -9,22 +9,21 @@ import pytest
 import numpy as np
 
 
-
 pytest_benchmark = get_pytest_benchmark(group="core.polyline")
 
 
 def test_init_numpy_array():
-    pl = Polyline(np.random.random((10,3)))
-    assert pl.vertices.shape == (10,3)
+    pl = Polyline(np.random.random((10, 3)))
+    assert pl.vertices.shape == (10, 3)
 
 
 def test_init_list_points():
     pl = Polyline([Point(x) for x in range(2)])
-    assert np.all(pl.vertices == np.array([[0,0,0],[1,0,0]]))
+    assert np.all(pl.vertices == np.array([[0, 0, 0], [1, 0, 0]]))
 
 
 def test_polyline_to_shapely():
-    pl = Polyline(np.random.random((10,3)))
+    pl = Polyline(np.random.random((10, 3)))
     assert isinstance(pl.to_shapely(), geometry.LineString)
 
 
@@ -37,28 +36,28 @@ def test_line_transform_identity(benchmark):
 
 
 def test_polyline_to_shapely_single_point():
-    pl = Polyline(np.random.random((1,3)))
+    pl = Polyline(np.random.random((1, 3)))
     assert isinstance(pl.to_shapely(), geometry.Point)
 
 
 def test_len_polyline():
-    pl = Polyline(np.random.random((10,3)))
+    pl = Polyline(np.random.random((10, 3)))
     assert len(pl) == 10
 
 
 def test_append():
-    pl = Polyline(np.random.random((10,3)))
-    pl2 = pl.append(Point())
-    assert isinstance(pl2, Polyline)
-    assert len(pl2) == 11
+    pl = Polyline(np.random.random((10, 3)))
+    pl.append(Point())
+    assert len(pl) == 11
+    assert pl[10] == Point()
 
 
 def test_extent():
-    pl1 = Polyline(np.random.random((10,3)))
-    pl2 = Polyline(np.random.random((10,3)))
-    pl3 = pl1.extent(pl2)
-    assert isinstance(pl3, Polyline)
-    assert len(pl3) == 20
+    pl1 = Polyline(np.random.random((10, 3)))
+    pl2 = Polyline(np.random.random((10, 3)))
+    pl1.extent(pl2)
+    assert isinstance(pl1, Polyline)
+    assert len(pl1) == 20
 
 
 @pytest_benchmark
@@ -93,7 +92,7 @@ def test_distance_to_index(benchmark):
 
 def test_index_distance_reciprocal():
     for _ in range(10):
-        pl = Polyline(np.random.random((10,3)))
+        pl = Polyline(np.random.random((10, 3)))
         index = np.random.random() * pl.get_total_distance()
         distance = pl.index_to_distance(index)
         assert pytest.approx(pl.distance_to_index(distance)) == index
@@ -103,7 +102,7 @@ def test_index_distance_reciprocal():
 def test_getitem_int(benchmark):
     pl = Polyline([Point(x) for x in range(10)])
     result = benchmark(pl.__getitem__, 5)
-    assert result == Point(5,0,0)
+    assert result == Point(5, 0, 0)
 
 
 @pytest_benchmark
@@ -120,7 +119,7 @@ def test_getitem_float_zero_decimal():
 
 def test_getitem_slice_integers():
     pl = Polyline([Point(x) for x in range(10)])
-    assert np.all(pl[2:5].vertices == Polyline([Point(x) for x in range(2,5)]).vertices)
+    assert np.all(pl[2:5].vertices == Polyline([Point(x) for x in range(2, 5)]).vertices)
 
 
 def test_getitem_slice_floats():
@@ -139,12 +138,14 @@ def test_polyline_get_tangent_angles(benchmark):
     pl = Polyline([Point(x, x) for x in range(5)])
     tangents = benchmark(pl.get_tangent_angles)
     assert tangents.size == len(pl)
-    assert np.all(tangents == pytest.approx(np.pi/4))
+    assert np.all(tangents == pytest.approx(np.pi / 4))
 
 
 @pytest_benchmark
 def test_polyline_get_radius_of_curvature(benchmark):
-    pl = Polyline([Point(*spherical_to_cartesian(5, theta, np.pi/2)) for theta in np.arange(-np.pi/2, np.pi/2, 0.1)])
+    pl = Polyline(
+        [Point(*spherical_to_cartesian(5, theta, np.pi / 2)) for theta in np.arange(-np.pi / 2, np.pi / 2, 0.1)]
+    )
     radius_of_curvature = benchmark(pl.get_radius_of_curvature)
     assert radius_of_curvature.size == len(pl)
     assert np.all(radius_of_curvature == pytest.approx(5, rel=1e-2))
