@@ -1,4 +1,8 @@
-from openride import BoundingBox, BoundingBoxCollection, Point, Polyline, Polygon, PointCloud, Category, SubCategory
+from openride import BoundingBox, BoundingBoxCollection
+from openride import Point, Polyline, Polygon, PointCloud
+from openride import Category, SubCategory
+from openride import Transform
+from openride.core.numba.transforms import transform_point
 from openride.viewer import vtk_utils
 from openride.viewer.camera import Camera
 from openride.viewer.interactor import Interactor
@@ -14,7 +18,7 @@ import vtk
 class Viewer:
     def __init__(
         self,
-        resolution=(1600, 900),
+        resolution: Tuple[int, int] = (1600, 900),
         background: Tuple[float, float, float] = (0.05, 0.05, 0.1),
         mouse_camera_interactions: bool = True,
     ):
@@ -205,12 +209,12 @@ class Viewer:
         start: Point,
         end: Point,
         color: tuple = (1, 1, 1),
-        alpha: float = 1,
+        alpha: float = 1.0,
         linewidth: int = 10,
-        headsize: float = 1,
+        headsize: float = 1.0,
         persist: bool = False,
     ):
-        self.draw_polyline(Polyline([start, end]), color=color, alpha=alpha, linewidth=linewidth)
+        self.draw_polyline(Polyline([start, end]), color=color, alpha=alpha, linewidth=linewidth, persist=persist)
         actor = vtk_utils.get_cone_actor(
             start.x,
             start.y,
@@ -224,6 +228,26 @@ class Viewer:
         )
         self.render_actor(actor, persist)
 
+    def draw_transform(
+        self,
+        transform: Transform,
+        ax_length: float = 1.0,
+        alpha: float = 1.0,
+        linewidth: int = 10,
+        headsize: float = 0.1,
+        persist: bool = False,
+    ):
+        origin = transform.translation
+        matrix = transform.get_matrix()
+
+        for ax, color in zip(
+            ((ax_length, 0, 0), (0, ax_length, 0), (0, 0, ax_length)), ((1, 0, 0), (0, 1, 0), (0, 0, 1))
+        ):
+            end = Point(*transform_point(*ax, matrix))
+            self.draw_arrow(
+                origin, end, color=color, alpha=alpha, linewidth=linewidth, headsize=headsize, persist=persist
+            )
+
     def draw_grid(
         self,
         origin: Point = Point(),
